## Repository regarding the thorondor package
This repository is the parent folder of the thorondor package, it contains the main program, meant to be imported via `pip install thorondor`.
There is also an example notebook in the example folder.

# Future work:
* Try to make a better use of voila packagen it works so far but not crazy, maybe just for plotting in big window
* Better import data tool
